OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bokmerker",
    "You deleted \"%s\"" : "Du slettet \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s slettet \"%2$s\"",
    "Someone deleted \"%s\"" : "Noen slettet \"%s\"",
    "You created folder \"%s\"" : "Du opprettet mappen \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s opprettet mappen \"%2$s\"",
    "Someone created folder \"%s\"" : "Noen opprettet mappen \"%s\"",
    "You moved folder \"%s\"" : "Du flyttet mappen \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s flyttet mappen \"%2$s\"",
    "Someone moved folder \"%s\"" : "Noen flyttet mappen \"%s\"",
    "You deleted folder \"%s\"" : "Du slettet mappen \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s slettet mappen \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Noen slettet mappen \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Du delte mappen \"%1$s\" med %2$s",
    "You shared folder \"%s\" with someone" : "Du delte mappen \"%s\" med noen",
    "%1$s shared folder \"%2$s\" with you" : "%1$s delte mappen \"%2$s\" med deg",
    "Someone shared folder \"%s\" with you" : "Noen delte mappen \"%s\" med deg",
    "No file provided for import" : "Ingen fil valgt for import",
    "Unsupported file type for import" : "Usupportert filtype for import",
    "Details" : "Detaljer",
    "Rename" : "Gi nytt navn",
    "Move" : "Flytt",
    "Delete" : "Slett",
    "Select one or more tags" : "Velg en eller flere merkelapper",
    "New" : "Ny",
    "New folder" : "Ny mappe",
    "Grid view" : "Rutenett-visning",
    "List view" : "Listevisning",
    "Select all" : "Velg alle",
    "Enter a link" : "Skriv inn et lenke",
    "Enter folder title" : "Skriv inn tittel",
    "Root folder" : "Hovedmappe",
    "Cancel" : "Avbryt",
    "Recent" : "Nylig",
    "Add a bookmark" : "Legg til bokmerke",
    "Import" : "Importer",
    "Export" : "Eksporter",
    "Sorting" : "Sorter",
    "Recently added" : "Nylig lagt til",
    "Alphabetically" : "Alfabetisk",
    "Most visited" : "Mest besøkt",
    "Last modified" : "Sist redigert",
    "Bookmarklet" : "Bookmarklet",
    "Clear data" : "Tøm data",
    "Delete all bookmarks" : "Slett alle bokmerker",
    "Do you really want to delete all your bookmarks?" : "Er du sikker på at du vil slette alle dine bokmerker",
    "Title" : "Tittel",
    "Link" : "Lenke",
    "Creation date" : "Opprettelses dato",
    "Tags" : "Merkelapper",
    "Attachments" : "Vedlegg",
    "Notes" : "Notater",
    "Owner" : "Eier",
    "Sharing" : "Deling",
    "Share link" : "Share link",
    "Copy link" : "Kopier lenke",
    "Allow editing" : "Tillat redigering",
    "Link copied" : "Lenke kopiert",
    "Select" : "Velg",
    "Privacy" : "Personvern",
    "Performance" : "Ytelse",
    "Failed to load settings" : "Klarte ikke å laste inn innstillinger",
    "Failed to save settings" : "Klarte ikke å lagre innstillinger",
    "This URL is already bookmarked! Overwrite?" : "Denne lenken eksisterer allerede, ønsker du overskrive?",
    "Enter bookmark title" : "Skriv inn tittel",
    "Folder" : "Mappe",
    "Save" : "Lagre",
    "Failed to create bookmark" : "Klarte ikke å opprette bokmerke",
    "Bookmarks feed" : "Bokmerker-strøm"
},
"nplurals=2; plural=(n != 1);");
